***********
Communities
***********

.. automodule:: networkx.algorithms.community
.. currentmodule:: networkx

K-Clique
^^^^^^^^
.. automodule:: networkx.algorithms.community.kclique
.. autosummary::
   :toctree: generated/

   k_clique_communities
